==> go.php?file=PhoenixStyle1.56205.zip: PhoenixStyleMod_DragonSoul/Localization/localization-ruRU.lua <==
﻿if GetLocale() == "ruRU" then


function psdragslocale()

psdragslastmoduleloadtxt	= "Душа Дракона"

pszzdragoboss7          = "Хребет Смертокрыла"
pszzdragoboss8          = "Безумие Смертокрыла"

pszzdragotxtopt613			= "|tip1 Сообщать если кто умер от атаки босса имея при этом более 1 стака |sid33661|id"
pszzdragotxtopt621			= "|tip2 Сколько лечения получил босс от |sid104322|id и кто виноват"
pszzdragotxtopt622			= "|tip1 Если более 1го рейдера получило урон от |sid104322|id"
pszzdragotxtopt645			= "|tip1 Сообщать кол-во стаков при смерти от |sid107062|id"
pszzdragotxtopt664			= "|tip1 Инфо о дебаффе |sid109204|id если кто-то умер от |sid109227|id или |sid109205|id"
pszzdragotxtopt671			= "|cff00ff00Boss_shieldsmonitor|r - отображать поглощаемое ХП: |sid109362|id, если установлен доп. аддон"
pszzdragotxtopt672			= "|tip2 Кто лечил |sid105479|id (поглощено)"
pszzdragotxtopt674			= "|tip3 'Данные об уроне' - сохранять информацию об уроне в Чудовищное слияние (посл. 10%) и Горящие Сухожилия"
pszzdragotxtopt675			= "|tip1 Кто наносил урон в Чудовищное слияние (посл. 10%) если он умер не применив заклинание |sid105845|id"
pszzdragotxtopt681			= "|tip3 'Данные об уроне' - сохранять информацию об уроне в Элементиевая стрела"
pszzdragotxtopt682      = "|tip2 Общее количество уменьшеного урона (примерно) благодаря использованию заклинания |sid106466|id"
pszzdragotxtopt683      = "|tip2 Кто ниразу не использовал заклинание |sid106466|id"


pszzdragotxtoptt672     = "Поглощенное лечение |s4id105479,109362,109363,109364|id"
pszzdragotxtoptt622	= "|s4id104322,104606,104607,104608|id задел %s"
pszzdragonly10		= "только <10% ХП"
pszzdragdamageinfly	= "только до взрыва"
pszzdragdamageinfly2	= "весь урон (без замедления)"
pszzdragotxtoptt682     = "|s4id106466,109634,109635,109636|id поглощенный урон (примерно)"
pszzdragtextbuttonuse1	= "|s4id106466,109634,109635,109636|id использовали только"
pszzdragtextbuttonuse2	= "|s4id106466,109634,109635,109636|id НЕ БЫЛ использован"
pszzdragtextbuttonuse3 	= "|s4id106466,109634,109635,109636|id НЕ БЫЛ использован %s игроками!"
pszzdraghpontheendcast	= "ХП оставшееся на конец каста"

end


end

==> go.php?file=PhoenixStyle1.56304.zip: PhoenixStyleMod_DragonSoul/Localization/localization-ruRU.lua <==
﻿if GetLocale() == "ruRU" then


function psdragslocale()

psdragslastmoduleloadtxt	= "Душа Дракона"

pszzdragoboss7          = "Хребет Смертокрыла"
pszzdragoboss8          = "Безумие Смертокрыла"

pszzdragotxtopt613			= "|tip1 Сообщать если кто умер от атаки босса имея при этом более 1 стака |sid33661|id"
pszzdragotxtopt621			= "|tip2 Сколько лечения получил босс от |sid104322|id и кто виноват"
pszzdragotxtopt622			= "|tip1 Если более 1го рейдера получило урон от |sid104322|id"
pszzdragotxtopt645			= "|tip1 Сообщать кол-во стаков при смерти от |sid107062|id"
pszzdragotxtopt664			= "|tip1 Инфо о дебаффе |sid109204|id если кто-то умер от |sid109227|id или |sid109205|id"
pszzdragotxtopt665			= "|tip1 Сообщать детальное инфо если кто умер от |sid109227|id или |sid109205|id"
pszzdragotxtopt671			= "|cff00ff00Boss_shieldsmonitor|r - отображать поглощаемое ХП: |sid109362|id, если установлен доп. аддон"
pszzdragotxtopt672			= "|tip2 Кто лечил |sid105479|id (поглощено)"
pszzdragotxtopt674			= "|tip3 'Данные об уроне' - сохранять информацию об уроне в Чудовищное слияние (посл. 10%) и Горящие Сухожилия"
pszzdragotxtopt675			= "|tip1 Кто наносил урон в Чудовищное слияние (посл. 10%) если он умер не применив заклинание |sid105845|id"
pszzdragotxtopt681			= "|tip3 'Данные об уроне' - сохранять информацию об уроне в Элементиевая стрела"
pszzdragotxtopt682      = "|tip2 Общее количество уменьшеного урона (примерно) благодаря использованию заклинания |sid106466|id"
pszzdragotxtopt683      = "|tip2 Кто ниразу не использовал заклинание |sid106466|id"
pszzdragotxtopt684      = "|tip1 Сообщать если кто умер от |sid110139|id не использовав |sid106466|id (нормал) или другие персональные приемы (героич.)"
pszzdragotxtopt685      = "|tip4 Вешать метки на мобов что читают заклинание |sid110139|id в игроков у которых нет доступных приемов для предотвращения урона"


pszzdragotxtoptt672     = "Поглощенное лечение |s4id105479,109362,109363,109364|id"
pszzdragotxtoptt622	= "|s4id104322,104606,104607,104608|id задел %s"
pszzdragonly10		= "только <10% ХП"
pszzdragdamageinfly	= "только до взрыва"
pszzdragdamageinfly2	= "весь урон (без замедления)"
pszzdragotxtoptt682     = "|s4id106466,109634,109635,109636|id поглощенный урон (примерно)"
pszzdragtextbuttonuse1	= "|s4id106466,109634,109635,109636|id использовали только"
pszzdragtextbuttonuse2	= "|s4id106466,109634,109635,109636|id НЕ БЫЛ использован"
pszzdragtextbuttonuse3 	= "|s4id106466,109634,109635,109636|id НЕ БЫЛ использован %s игроками!"
pszzdraghpontheendcast	= "ХП оставшееся на конец каста"
pszzdragdiedtoquick     = "Умер не набрав 9 стаков!"
pszzdraghpremain         = "Оставшееся ХП"
pszzdragsplit           = "Разделили"
pszzdragdiedwarmast     = "Умер (ХП игрока перед лужей)"
pszzdragothercd         = "Доступные КД"
pszzdragdamagetoplayer  = "Урон по игроку"
pszzdragdamageto        = "Урон по"
pszzdraghealedby        = "Отлечено"

end


end
